pub enum Marker<'a> {
Show 17 variants
NodeConnectedToNetwork,
NoNetworkActivity(Duration),
ForcedReplication,
NodeCmdReceived(&'a Cmd),
PeerAddedToRoutingTable(PeerId),
PeerRemovedFromRoutingTable(PeerId),
PeersInRoutingTable(usize),
ReplicationTriggered,
IntervalReplicationTriggered,
FetchingKeysForReplication {
fetching_keys_len: usize,
},
ValidChunkRecordPutFromNetwork(&'a PrettyPrintRecordKey<'a>),
ValidRegisterRecordPutFromNetwork(&'a PrettyPrintRecordKey<'a>),
ValidSpendRecordPutFromNetwork(&'a PrettyPrintRecordKey<'a>),
ValidPaidChunkPutFromClient(&'a PrettyPrintRecordKey<'a>),
ValidPaidRegisterPutFromClient(&'a PrettyPrintRecordKey<'a>),
ValidSpendPutFromClient(&'a PrettyPrintRecordKey<'a>),
RecordRejected(&'a PrettyPrintRecordKey<'a>, &'a Error),
}Expand description
Public Markers for generating log output, These generate appropriate log level output and consistent strings. Changing these log markers is a breaking change.
Variants
NodeConnectedToNetwork
The node has started
NoNetworkActivity(Duration)
No network activity in some time
ForcedReplication
Forced Replication by simulating a churned out node within close range.
NodeCmdReceived(&'a Cmd)
Network Cmd message received
PeerAddedToRoutingTable(PeerId)
Peer was added to the routing table
PeerRemovedFromRoutingTable(PeerId)
Peer was removed from the routing table
PeersInRoutingTable(usize)
The number of peers in the routing table
ReplicationTriggered
Replication trigger was fired
IntervalReplicationTriggered
Interval based replication
FetchingKeysForReplication
Keys of Records we are fetching to replicate locally
ValidChunkRecordPutFromNetwork(&'a PrettyPrintRecordKey<'a>)
Valid non-existing Chunk record PUT from the network received and stored
ValidRegisterRecordPutFromNetwork(&'a PrettyPrintRecordKey<'a>)
Valid non-existing Register record PUT from the network received and stored
ValidSpendRecordPutFromNetwork(&'a PrettyPrintRecordKey<'a>)
Valid non-existing Spend record PUT from the network received and stored
ValidPaidChunkPutFromClient(&'a PrettyPrintRecordKey<'a>)
Valid paid to us and royalty paid chunk stored
ValidPaidRegisterPutFromClient(&'a PrettyPrintRecordKey<'a>)
Valid paid to us and royalty paid register stored
ValidSpendPutFromClient(&'a PrettyPrintRecordKey<'a>)
Valid spend stored
RecordRejected(&'a PrettyPrintRecordKey<'a>, &'a Error)
Record rejected
Implementations