Type Definition sn_node::NodeEventsReceiver
source · pub type NodeEventsReceiver = Receiver<NodeEvent>;Expand description
Type of channel receiver where events are broadcasted to by the node.
pub type NodeEventsReceiver = Receiver<NodeEvent>;Type of channel receiver where events are broadcasted to by the node.